netapp_ontap.models.volume_clone API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_clone`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeCloneSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeClone object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `is_flexclone GET POST PATCH`

    Specifies if this volume is a normal FlexVol or FlexClone. This field needs to be set when creating a FlexClone. Valid in POST.

  `parent_snapshot GET POST PATCH`

    The parent_snapshot field of the volume_clone.

  `parent_svm GET POST PATCH`

    The parent_svm field of the volume_clone.

  `parent_volume GET POST PATCH`

    The parent_volume field of the volume_clone.

  `split_complete_percent GET`

    Percentage of FlexClone blocks split from its parent volume.

  `split_estimate GET`

    Space required by the containing-aggregate to split the FlexClone volume.

  `split_initiated GET POST PATCH`

    This field is set when split is executed on any FlexClone, that is when the FlexClone volume is split from its parent FlexVol. This field needs to be set for splitting a FlexClone form FlexVol. Valid in PATCH.